# German Credit Data

## Source / Data Set Description:
<https://archive.ics.uci.edu/ml/datasets/Statlog+%28German+Credit+Data%29>

This dataset classifies people described by a set of attributes as good or bad credit risks. File used is `german.data` consisting of 1000 instances and 20 features.
Detailed description of the dataset is provided in `german.doc`.

## Download instructions

Download the following files and place them as-is in the current folder

1. [german.data](https://archive.ics.uci.edu/ml/machine-learning-databases/statlog/german/german.data)

2. [german.doc](https://archive.ics.uci.edu/ml/machine-learning-databases/statlog/german/german.doc)

